default_app_config = 'django_ledger.apps.DjangoLedgerConfig'


"""Django Ledger"""
__version__ = '0.2.9'
__license__ = 'GPLv3 License'

__author__ = 'Miguel Sanda'
__email__ = 'msanda@arrobalytics.com'

__url__ = 'https://arrobalytics.com'